import * as azure from "@pulumi/azure";
import * as pulumi from "@pulumi/pulumi";
import * as azurefunctions from "azure-functions-ts-essentials";
export interface Context extends azurefunctions.Context {
    log: {
        (...message: Array<any>): void;
        error(...message: Array<any>): void;
        warn(...message: Array<any>): void;
        info(...message: Array<any>): void;
        verbose(...message: Array<any>): void;
        metric(...message: Array<any>): void;
    };
}
/**
 * A synchronous function that can be converted into an Azure FunctionApp. This callback should
 * return nothing, and should signal that it is done by calling `context.Done()`. Errors can be
 * signified by calling `context.Done(err)`
 */
export declare type Callback<C extends Context, Data> = (context: C, data: Data) => void;
export interface EventSubscriptionArgs {
    /**
     * The resource group to create the serverless FunctionApp within.  If not provided, a new
     * resource group will be created with the same name as the pulumi resource. It will be created
     * in the region specified by the config variable "azure:region"
     */
    resourceGroup: azure.core.ResourceGroup;
    /**
     * The storage account to use where the zip-file blob for the FunctionApp will be located. If
     * not provided, a new storage account will create. It will be a 'Standard', 'LRS', 'StorageV2'
     * account.
     */
    storageAccount?: azure.storage.Account;
    /**
     * The container to use where the zip-file blob for the FunctionApp will be located. If not
     * provided, the root container of the storage account will be used.
     */
    storageContainer?: azure.storage.Container;
    /**
     * The consumption plan to put the FunctionApp in.  If not provided, a 'Dynamic', 'Y1' plan will
     * be used.  See https://social.msdn.microsoft.com/Forums/azure/en-US/665c365d-2b86-4a77-8cea-72ccffef216c for
     * additional details.
     */
    appServicePlan?: azure.appservice.Plan;
    /**
     * A key-value map to use as the 'App Settings' for this function.
     */
    appSettings?: pulumi.Output<Record<string, string>>;
}
/**
 * Represents a Binding that will be emitted into the function.json config file for the FunctionApp.
 * Individual services will have more specific information they will define in their own bindings.
 */
export interface Binding {
    type: string;
    direction: string;
    name: string;
}
/**
 * Base type for all subscription types.
 */
export declare class EventSubscription<C extends Context, Data> extends pulumi.ComponentResource {
    readonly resourceGroup: azure.core.ResourceGroup;
    readonly storageAccount: azure.storage.Account;
    readonly storageContainer: azure.storage.Container;
    readonly appServicePlan: azure.appservice.Plan;
    /**
     * The FunctionApp instance created to respond to the specific Binding triggers.  The
     * code for it will be produced by serializing out the 'callback' parameter using pulumi
     * serialization.
     */
    readonly functionApp: azure.appservice.FunctionApp;
    constructor(type: string, name: string, callback: Callback<C, Data>, bindings: pulumi.Input<Binding[]>, args: EventSubscriptionArgs, options?: pulumi.ResourceOptions);
}
