"use strict";
// Copyright 2016-2018, Pulumi Corporation.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const azure = require("@pulumi/azure");
function signedBlobReadUrl(blob, account, container) {
    // Choose a fixed, far-past and far-future expiration date for signed blob URLs.
    // The shared access signature (SAS) we generate for the Azure storage blob must remain valid for as long as the
    // Function App is deployed, since new instances will download the code on startup. By using a fixed date, rather
    // than (e.g.) "today plus ten years", the signing operation is idempotent.
    const signatureStart = new Date(0);
    const signatureExpiration = new Date(2100, 1);
    return blob.url.apply((blobUrl) => __awaiter(this, void 0, void 0, function* () {
        const accountSAS = yield azure.storage.getAccountSAS({
            connectionString: account.primaryConnectionString,
            start: signatureStart.toISOString(),
            expiry: signatureExpiration.toISOString(),
            permissions: {
                read: true,
                write: false,
                create: false,
                add: false,
                list: false,
                delete: false,
                update: false,
                process: false,
            },
            services: {
                blob: true,
                file: false,
                queue: false,
                table: false,
            },
            resourceTypes: {
                object: true,
                container: false,
                service: false,
            },
        });
        return blobUrl + accountSAS.sas;
    }));
}
exports.signedBlobReadUrl = signedBlobReadUrl;
//# sourceMappingURL=util.js.map